@@ -30,7 +30,7 @@
 #include "dvdauthor.h"
 #include "da-internal.h"
 
-static const char RCSID[]="$Id: //depot/dvdauthor/src/dvdauthor.c#72 $";
+static const char RCSID[]="$Id: //depot/dvdauthor/src/dvdauthor.c#73 $";
 
 
 
@@ -103,7 +103,7 @@ int getratedenom(struct vobgroup *va)
     return ratedenom[getratecode(va)];
 }
 
-int getframepts(struct vobgroup *va)
+pts_t getframepts(struct vobgroup *va)
 {
     int rc=getratecode(va);
 
@@ -571,14 +571,14 @@ int findcellvobu(struct vob *va,int cellid)
     return l;
 }
 
-int getcellpts(struct vob *va,int cellid)
+pts_t getcellpts(struct vob *va,int cellid)
 {
     int s=findcellvobu(va,cellid),e=findcellvobu(va,cellid+1);
     if( s==e ) return 0;
     return va->vi[e-1].sectpts[1]-va->vi[s].sectpts[0];
 }
 
-int findvobu(struct vob *va,int pts,int l,int h)
+int findvobu(struct vob *va,pts_t pts,int l,int h)
 {
     // int l=0,h=va->numvobus-1;
 
@@ -598,9 +598,10 @@ int findvobu(struct vob *va,int pts,int l,int h)
     return l;
 }
 
-int getptsspan(struct pgc *ch)
+pts_t getptsspan(struct pgc *ch)
 {
-    int ptsspan=0,s,c,ci;
+    int s,c,ci;
+    pts_t ptsspan=0;
 
     for( s=0; s<ch->numsources; s++ ) {
         struct source *sc=ch->sources[s];
