@@ -29,7 +29,7 @@
 #include "readxml.h"
 #include "rgb.h"
 
-static const char RCSID[]="$Id: //depot/dvdauthor/src/dvdcli.c#50 $";
+static const char RCSID[]="$Id: //depot/dvdauthor/src/dvdcli.c#52 $";
 
 #define RGB2YCrCb(R,G,B) ((((int)RGB2Y(R,G,B))<<16)|(((int)RGB2Cr(R,G,B))<<8)|(((int)RGB2Cb(R,G,B))))
 
@@ -172,8 +172,7 @@ static void parsechapters(char *o,struct source *src,int pauselen)
 
 static void readpalette(struct pgc *p,const char *fname)
 {
-    int i,b,rgbf;
-    unsigned char groups[24];
+    int i,rgbf;
     FILE *h;
 
     if(fname[0] == '&' && isdigit(fname[1]) )
@@ -201,6 +200,9 @@ static void readpalette(struct pgc *p,const char *fname)
     }
 
 #if 0
+    int b;
+    unsigned char groups[24];
+
     memset(groups,0,24);
     i=0;
     while(fscanf(h,"%x",&b) == 1 && i<24 ) {
@@ -813,7 +815,9 @@ static void pgc_start()
 
 static void pgc_entry(char *e)
 {
-    pgc_add_entry(curpgc,e);
+    // xml attributes can only be defined once, so entry="foo" entry="bar" won't work
+    // instead, use parseentries...
+    parseentries(curpgc,e);
 }
 
 static void pgc_palette(char *p)
