@@ -23,9 +23,9 @@
 
 #include "dvdauthor.h"
 #include "da-internal.h"
-#include "vm.h"
+#include "dvdvm.h"
 
-static const char RCSID[]="$Id: //depot/dvdauthor/src/dvdcompile.c#13 $";
+static const char RCSID[]="$Id: //depot/dvdauthor/src/dvdcompile.c#15 $";
 
 struct vm_statement *dvd_vm_parsed_cmd;
 
@@ -505,7 +505,12 @@ static unsigned char *compilecs(unsigned char *obuf,unsigned char *buf,struct wo
                         return 0;
                     }
                 }
-                write8(buf,0x20,0x04,0x00,0x00,0x00,0x00,0x00,cs->i2&127);
+                if( ismenu==2 ) {
+                    // In case we are jumping from a FP to VMGM, we need to use a JumpSS
+                    // instruction
+                    write8(buf,0x30,0x06,0x00,cs->i2&127,0x00,0xc0,0x00,0x00); // JumpSS VMGM pgcn
+                } else
+                    write8(buf,0x20,0x04,0x00,0x00,0x00,0x00,0x00,cs->i2&127); // LinkPGCN
                 buf+=8;
             } else {
                 //	VMGM	NONE	TPGC	NOCH
