@@ -30,7 +30,7 @@
 
 #include <netinet/in.h>
 
-static const char RCSID[]="$Id: //depot/dvdauthor/src/mpeg2desc.c#32 $";
+static const char RCSID[]="$Id: //depot/dvdauthor/src/mpeg2desc.c#33 $";
 
 // #define SHOWDATA
 
@@ -273,7 +273,7 @@ void writetostream(int stream,unsigned char *buf,int len)
 
 int main(int argc,char **argv)
 {
-    unsigned int hdr=0;
+    unsigned int hdr=0, mpeg2=1;
     unsigned char c,buf[200];
     int outputenglish=1,outputstream=0,oc, i,skiptohdr=0,audiodrop=0,nounknown=0;
 
@@ -448,31 +448,39 @@ int main(int argc,char **argv)
         {
             long scr,scrhi,scrext;
             int64_t fulltime;
-            forceread(buf,10,stdin);
-            if( buf[9]&7 ) {
-                printf("WARN: pack padding\n");
+            forceread(buf,8,stdin);
+            if((buf[0] & 0xC0) == 0x40) {
+	        forceread(buf+8,2,stdin);
+                scrhi=(buf[0]&0x20)>>5;
+                scr=((buf[0]&0x18)<<27)|
+                    ((buf[0]&3)<<28)|
+                    (buf[1]<<20)|
+                    ((buf[2]&0xf8)<<12)|
+                    ((buf[2]&3)<<13)|
+                    (buf[3]<<5)|
+                    ((buf[4]&0xf8)>>3);
+                scrext=((buf[4]&3)<<7)|
+                    (buf[5]>>1);
+                if( scrext >= 300 && outputenglish ) {
+                    printf("WARN: scrext in pack hdr > 300: %ld\n",scrext);
+                }
+                fulltime=((int64_t)scrhi)<<32|((int64_t)scr);
+                fulltime*=300;
+                fulltime+=scrext;
+                mpeg2 = 1;
+	    } else if((buf[0] & 0xF0) == 0x20) {
+                mpeg2 = 0;
+		fulltime=readpts(buf);
+                fulltime*=300;
+	    } else {
+                if( outputenglish )
+                    printf("WARN: unknown pack header version\n");
+                fulltime=0;
             }
-            if( (buf[0] & 0xC0) != 0x40 && outputenglish) {
-                printf("WARN: not an mpeg2 pack header\n");
-            }
-            scrhi=(buf[0]&0x20)>>5;
-            scr=((buf[0]&0x18)<<27)|
-                ((buf[0]&3)<<28)|
-                (buf[1]<<20)|
-                ((buf[2]&0xf8)<<12)|
-                ((buf[2]&3)<<13)|
-                (buf[3]<<5)|
-                ((buf[4]&0xf8)>>3);
-            scrext=((buf[4]&3)<<7)|
-                (buf[5]>>1);
-            if( scrext >= 300 && outputenglish ) {
-                printf("WARN: scrext in pack hdr > 300: %ld\n",scrext);
-            }
-            fulltime=((int64_t)scrhi)<<32|((int64_t)scr);
-            fulltime*=300;
-            fulltime+=scrext;
+
             if( outputenglish )
-                printf("%08x: pack hdr, %lld.%03lld sec\n",disppos,fulltime/SCRTIME,(fulltime%SCRTIME)/(SCRTIME/1000));
+                printf("%08x: mpeg%c pack hdr, %lld.%03lld sec\n",disppos,mpeg2?'2':'1',fulltime/SCRTIME,(fulltime%SCRTIME)/(SCRTIME/1000));
+            
             forceread(&hdr,4,stdin);
             break;
         }
@@ -579,63 +587,92 @@ int main(int argc,char **argv)
                 printf("; length=%d",extra+readlen);
                 if( ext ) {
                     int eptr=3;
+		    int hdr=0, has_pts, has_dts, has_std=0, std=0, std_scale=0;
+		    
+		    if((buf[0] & 0xC0) == 0x80) {
+		        mpeg2 = 1;
+			hdr = buf[2]+3;
+			eptr = 3;
+			has_pts = buf[1] & 128;
+			has_dts = buf[1] & 64;
+                    }
+                    else {
+		        mpeg2 = 0;
+			while((buf[hdr] == 0xff) && (hdr<sizeof(buf)))
+			    hdr++;
+                        if((buf[hdr] & 0xC0) == 0x40) {
+			    has_std = 1;
+			    std_scale = ((buf[hdr]&32)?1024:128);
+			    std = ((buf[hdr]&31)*256+buf[hdr+1])*std_scale;
+			    hdr+=2;
+                        } else has_std = 0;
+                        eptr = hdr;
+			has_pts = (buf[hdr] & 0xE0) == 0x20;
+			has_dts = (buf[hdr] & 0xF0) == 0x30;
+                    }
 
-                    printf("; hdr=%d",buf[2]+3);
-                    if( buf[1] & 128 ) {
+                    printf("; hdr=%d",hdr);
+                    if( has_pts ) {
                         int64_t pts;
                         
                         pts=readpts(buf+eptr);
                         eptr+=5;
                         printf("; pts %lld.%03lld sec",pts/PTSTIME,(pts%PTSTIME)/(PTSTIME/1000));
                     }
-                    if( buf[1] & 64 ) {
+                    if( has_dts ) {
                         int64_t dts;
                     
                         dts=readpts(buf+eptr);
                         eptr+=5;
                         printf("; dts %lld.%03lld sec",dts/PTSTIME,(dts%PTSTIME)/(PTSTIME/1000));
                     }
-                    if( buf[1] & 32 ) {
-                        printf("; escr");
-                        eptr+=6;
-                    }
-                    if( buf[1] & 16 ) {
-                        printf("; es");
-                        eptr+=2;
-                    }
-                    if( buf[1] & 4 ) {
-                        printf("; ci");
-                        eptr++;
-                    }
-                    if( buf[1] & 2 ) {
-                        printf("; crc");
-                        eptr+=2;
-                    }
-                    if( buf[1] & 1 ) {
-                        int pef=buf[eptr];
-                        eptr++;
-                        printf("; (pext)");
-                        if( pef & 128 ) {
-                            printf("; user");
-                            eptr+=16;
+		    if(mpeg2) {
+                        if( buf[1] & 32 ) {
+                            printf("; escr");
+                            eptr+=6;
                         }
-                        if( pef & 64 ) {
-                            printf("; pack");
+                        if( buf[1] & 16 ) {
+                            printf("; es");
+                            eptr+=2;
+                        }
+                        if( buf[1] & 4 ) {
+                            printf("; ci");
                             eptr++;
                         }
-                        if( pef & 32 ) {
-                            printf("; ppscf");
+                        if( buf[1] & 2 ) {
+                            printf("; crc");
                             eptr+=2;
                         }
-                        if( pef & 16 ) {
-                            printf("; pstd=%d",((buf[eptr]&31)*256+buf[eptr+1])*((buf[eptr]&32)?1024:128));
-                            eptr+=2;
+                        if( buf[1] & 1 ) {
+                            int pef=buf[eptr];
+                            eptr++;
+                            printf("; (pext)");
+                            if( pef & 128 ) {
+                                printf("; user");
+                                eptr+=16;
+                            }
+                            if( pef & 64 ) {
+                                printf("; pack");
+                                eptr++;
+                            }
+                            if( pef & 32 ) {
+                                printf("; ppscf");
+                                eptr+=2;
+                            }
+                            if( pef & 16 ) {
+                                std_scale=((buf[eptr]&32)?1024:128);
+                                printf("; pstd=%d (scale=%d)",((buf[eptr]&31)*256+buf[eptr+1])*std_scale, std_scale);
+                                eptr+=2;
+                            }
+                            if( pef & 1 ) {
+                                printf("; (pext2)");
+                                eptr+=2;
+                            }
                         }
-                        if( pef & 1 ) {
-                            printf("; (pext2)");
-                            eptr+=2;
-                        }
-                    }
+		    } else {
+                        if(has_std)
+                            printf("; pstd=%d (scale=%d)",std, std_scale);
+		    }
                 }
                 printf("\n");
             }
