@@ -44,7 +44,7 @@
 #define CBUFSIZE 65536
 #define PSBUFSIZE 10
 
-static const char RCSID[]="$Id: //depot/dvdauthor/src/spuunmux.c#20 $";
+static const char RCSID[]="$Id: //depot/dvdauthor/src/spuunmux.c#21 $";
 
 static unsigned int add_offset;
 
@@ -345,7 +345,12 @@ static int dvddecode()
 	    if (++x == s->xd) {
 		y += 2;
 		x = 0;
-		io += s->xd;
+                if ((y >= s->yd) && !(y & 1)) {
+                    y = 1;
+                    io = s->xd;
+                    ofs = ofs1;
+                } else
+                    io += s->xd;
 		have_bits = FALSE;
 	    }
 	}
