@@ -31,7 +31,7 @@
 
 #include "config.h"
 
-static const char RCSID[]="$Id: //depot/dvdauthor/src/subfont.c#10 $";
+static const char RCSID[]="$Id: //depot/dvdauthor/src/subfont.c#12 $";
 
 #ifdef HAVE_FREETYPE
 
@@ -512,6 +512,7 @@ void render_one_glyph(font_desc_t *desc, int c)
 {
     FT_GlyphSlot	slot;
     FT_UInt		glyph_index;
+    FT_Glyph oglyph;
     FT_BitmapGlyph glyph;
     int width, height, stride, maxw, off;
     unsigned char *abuffer, *bbuffer;
@@ -551,12 +552,18 @@ void render_one_glyph(font_desc_t *desc, int c)
     }
 
     // extract glyph image
-    error = FT_Get_Glyph(slot, (FT_Glyph*)&glyph);
+    error = FT_Get_Glyph(slot, &oglyph);
     if (error) {
 	WARNING("FT_Get_Glyph 0x%04x (char 0x%04x) failed.", glyph_index, c);
 	desc->font[c] = -1;
 	return;
     }
+    if( oglyph->format != FT_GLYPH_FORMAT_BITMAP ) {
+        WARNING("FT_Get_Glyph did not return a bitmap glyph.");
+        desc->font[c] = -1;
+        return;
+    }
+    glyph=(FT_BitmapGlyph)oglyph;
 
 //    fprintf(stderr, "glyph generated\n");
 
@@ -759,8 +766,8 @@ static FT_ULong decode_char(iconv_t *cd, char c) {
     FT_ULong o;
     char *inbuf = &c;
     char *outbuf = (char*)&o;
-    int inbytesleft = 1;
-    int outbytesleft = sizeof(FT_ULong);
+    size_t inbytesleft = 1;
+    size_t outbytesleft = sizeof(FT_ULong);
 
     iconv(*cd, ICONV_CAST &inbuf, &inbytesleft, &outbuf, &outbytesleft);
 	o=ntohl(o);
