@@ -34,7 +34,7 @@
 #include "subgen.h"
 #include "textsub.h"
 
-static const char RCSID[]="$Id: //depot/dvdauthor/src/subgen-image.c#20 $";
+static const char RCSID[]="$Id: //depot/dvdauthor/src/subgen-image.c#23 $";
 
 #define MAXX 720
 #define MAXY 576
@@ -64,6 +64,9 @@ typedef struct {
 //
 // Bitmap reading code
 
+// this function scans through a picture and looks for the color that
+// the user indicated should mean transparent
+// if the color is found, it is replaced by 0,0,0,0 meaning "transparent"
 static void scanpict(stinfo *s,pict *p)
 {
     int i;
@@ -177,13 +180,18 @@ static int read_magick(pict *s)
             p.r=pdata[x*4];
             p.g=pdata[x*4+1];
             p.b=pdata[x*4+2];
+            // the meaning of RGBA swapped with ImageMagick 6.0.0...
+#if MagickLibVersion >= 0x600
+            p.t=pdata[x*4+3];
+#else
             p.t=255-pdata[x*4+3];
+#endif
             putpixel(s,y*s->width+x,&p);
         }
     }
     DestroyImage(im);
     DestroyExceptionInfo(&ei);
-    fprintf(stderr,"INFO: Picture had %d colors\n",s->numpal);
+    fprintf(stderr,"INFO: Picture %s had %d colors\n",s->fname,s->numpal);
 
     return 0;
 }
