@@ -35,7 +35,7 @@
 #include "subgen.h"
 #include "textsub.h"
 
-static const char RCSID[]="$Id: //depot/dvdauthor/src/subgen.c#48 $";
+static const char RCSID[]="$Id: //depot/dvdauthor/src/subgen.c#49 $";
 
 
 // (90000*300)/(1260000/2048)
@@ -407,10 +407,15 @@ static void mux(int eoinput)
 
         if(debug > 4)
         {
-            fprintf(stderr, "spts: %d  sd: %d  nspts: %d\n",\
-                    cursti->spts / 90000, cursti->sd / 90000, newsti->spts / 90000);
+            if( newsti ) {
+                fprintf(stderr, "spts: %d  sd: %d  nspts: %d\n",
+                        cursti->spts / 90000, cursti->sd / 90000, newsti->spts / 90000);
+            } else {
+                fprintf(stderr, "spts: %d  sd: %d  nspts: NULL\n",
+                        cursti->spts / 90000, cursti->sd / 90000);
+            }
         }
-
+        
         if( (cursti->sd == -1) && newsti && ( (!svcd) || until_next_sub) )
         {
             if(newsti->spts > cursti->spts + tbs) cursti->sd = newsti->spts - cursti->spts - tbs;
