@@ -34,7 +34,7 @@
 #include "subfont.h"
 
 
-static const char RCSID[]="$Id: //depot/dvdauthor/src/subrender.c#9 $";
+static const char RCSID[]="$Id: //depot/dvdauthor/src/subrender.c#10 $";
 
 
 #define NEW_SPLITTING
@@ -171,71 +171,73 @@ static void alloc_buf(mp_osd_obj_t* obj)
 
 // vo_draw_text_sub(int dxs,int dys,void (*draw_alpha)(int x0,int y0, int w,int h, unsigned char* src, unsigned char *srca, int stride))
 
-inline static void vo_update_text_sub(mp_osd_obj_t* obj,int dxs,int dys){
-   unsigned char *t;
-   int c,i,j,prev_j,l,x,y,font,prevc,counter;
-   int len;
-   int k;
-   int lastStripPosition;
-   int xsize,subs_height;
-   int xmin=dxs-sub_left_margin-sub_right_margin,xmax=0;
-   int h,lasth;
-   int xtblc, utblc;
-   obj->flags|=OSDFLAG_CHANGED|OSDFLAG_VISIBLE;
+inline static void vo_update_text_sub(mp_osd_obj_t* obj,int dxs,int dys)
+{
+    unsigned char *t;
+    int c,i,j,prev_j,l,x,y,font,prevc,counter;
+    int len;
+    int k;
+    int lastStripPosition;
+    int xsize,subs_height;
+    int xmin=dxs-sub_left_margin-sub_right_margin,xmax=0;
+    int h,lasth;
+    int xtblc, utblc;
+    obj->flags|=OSDFLAG_CHANGED|OSDFLAG_VISIBLE;
 
-   if(!vo_sub || !vo_font || !sub_visibility){
-       obj->flags&=~OSDFLAG_VISIBLE;
-	   return;
-   }
-   obj->bbox.y2=obj->y=dys-sub_bottom_margin;
-   obj->params.subtitle.lines=0;
+    if(!vo_sub || !vo_font || !sub_visibility){
+        obj->flags&=~OSDFLAG_VISIBLE;
+        return;
+    }
+    obj->bbox.y2=obj->y=dys-sub_bottom_margin;
+    obj->params.subtitle.lines=0;
 
-      // too long lines divide into a smaller ones
-      i=k=lasth=0;
-      h=vo_font->height;
-      lastStripPosition=-1;
-      l=vo_sub->lines;
+    // too long lines divide into a smaller ones
+    i=k=lasth=0;
+    h=vo_font->height;
+    lastStripPosition=-1;
+    l=vo_sub->lines;
 
     {
 	struct osd_text_t *osl, *cp_ott, *tmp_ott, *tmp;
-	struct osd_text_p *otp_sub = NULL, *otp_sub_tmp,	// these are used to store the whole sub text osd
-	                  *otp, *tmp_otp, *pmt;	// these are used to manage sub text osd coming from a single sub line
-	  /* int *char_seq, char_position, xlimit = dxs * sub_width_p / 100, counter; */
-	  int *char_seq, char_position, xlimit = dxs -sub_right_margin -sub_left_margin, counter;
+	struct osd_text_p *otp_sub = NULL, *otp_sub_tmp=NULL,	// these are used to store the whole sub text osd
+            *otp, *tmp_otp, *pmt;	// these are used to manage sub text osd coming from a single sub line
+        /* int *char_seq, char_position, xlimit = dxs * sub_width_p / 100, counter; */
+        int *char_seq, char_position, xlimit = dxs -sub_right_margin -sub_left_margin, counter;
 
-	  while (l) {
+        while (l) {
 	    xsize = -vo_font->charspace;
-	  l--;
-	  t=vo_sub->text[i++];
-	  len=strlen(t)-1;
+            l--;
+            t=vo_sub->text[i++];
+            len=strlen(t)-1;
 	    char_position = 0;
 	    char_seq = (int *) malloc((len + 1) * sizeof(int));
 
-	  prevc = -1;
+            prevc = -1;
 
 	    otp = NULL;
 	    osl = NULL;
+            cp_ott = NULL;
 	    x = 1;
 
 	    // reading the subtitle words from vo_sub->text[]
-	  for (j=0;j<=len;j++){
-	      if ((c=t[j])>=0x80){
-		 if (sub_utf8){
-		    if ((c & 0xe0) == 0xc0)    /* 2 bytes U+00080..U+0007FF*/
-		       c = (c & 0x1f)<<6 | (t[++j] & 0x3f);
-		    else if((c & 0xf0) == 0xe0){ /* 3 bytes U+00800..U+00FFFF*/
-		       c = (((c & 0x0f)<<6) | (t[++j] & 0x3f))<<6;
-		       c |= (t[++j] & 0x3f);
-		    }
-		 } else if (sub_unicode)
-		       c = (c<<8) + t[++j];
-	      }
-	      if (k==MAX_UCS){
-		 len=j; // end here
-		 fprintf(stderr,"WARN: MAX_UCS exceeded!\n");
-	      }
-	      if (!c) c++; // avoid UCS 0
-	      render_one_glyph(vo_font, c);
+            for (j=0;j<=len;j++){
+                if ((c=t[j])>=0x80){
+                    if (sub_utf8){
+                        if ((c & 0xe0) == 0xc0)    /* 2 bytes U+00080..U+0007FF*/
+                            c = (c & 0x1f)<<6 | (t[++j] & 0x3f);
+                        else if((c & 0xf0) == 0xe0){ /* 3 bytes U+00800..U+00FFFF*/
+                            c = (((c & 0x0f)<<6) | (t[++j] & 0x3f))<<6;
+                            c |= (t[++j] & 0x3f);
+                        }
+                    } else if (sub_unicode)
+                        c = (c<<8) + t[++j];
+                }
+                if (k==MAX_UCS){
+                    len=j; // end here
+                    fprintf(stderr,"WARN: MAX_UCS exceeded!\n");
+                }
+                if (!c) c++; // avoid UCS 0
+                render_one_glyph(vo_font, c);
 
 		if (c == ' ') {
 		    struct osd_text_t *tmp_ott = (struct osd_text_t *) calloc(1, sizeof(struct osd_text_t));
@@ -278,7 +280,7 @@ inline static void vo_update_text_sub(mp_osd_obj_t* obj,int dxs,int dys){
 			}
 		    }
 		}
-	  }// for len (all words from subtitle line read)
+            }// for len (all words from subtitle line read)
 
 	    // osl holds an ordered (as they appear in the lines) chain of the subtitle words
 	    {
@@ -301,18 +303,18 @@ inline static void vo_update_text_sub(mp_osd_obj_t* obj,int dxs,int dys){
 		char_position = 0;
 		xsize = -vo_font->charspace;
 	    }
-		if (osl != NULL) {
+            if (osl != NULL) {
 		int value = 0, exit1 = 0, minimum = 0;
 
 		// otp will contain the chain of the osd subtitle lines coming from the single vo_sub line.
 		otp = tmp_otp = (struct osd_text_p *) calloc(1, sizeof(struct osd_text_p));
 		tmp_otp->ott = osl;
 		for (tmp_ott = tmp_otp->ott; exit1 == 0; ) {
-			while ((tmp_ott != NULL) && (value + tmp_ott->osd_kerning + tmp_ott->osd_length <=xlimit)) {
+                    while ((tmp_ott != NULL) && (value + tmp_ott->osd_kerning + tmp_ott->osd_length <=xlimit)) {
 			value += tmp_ott->osd_kerning + tmp_ott->osd_length;
 			tmp_ott = tmp_ott->next;
 		    }
-			if (tmp_ott != NULL) {
+                    if (tmp_ott != NULL) {
 			struct osd_text_p *tmp = (struct osd_text_p *) calloc(1, sizeof(struct osd_text_p));
 
 			tmp_otp->value = value;
@@ -416,9 +418,9 @@ inline static void vo_update_text_sub(mp_osd_obj_t* obj,int dxs,int dys){
 	for (tmp_otp = otp_sub; tmp_otp != NULL; tmp_otp = tmp_otp->next) {
 
 	    if ((obj->params.subtitle.lines++) >= MAX_UCSLINES)
-		{fprintf(stderr,"WARN: max_ucs_lines\n");
-		break;}
-		if (h+sub_top_margin > obj->y) {	// out of the screen so end parsing
+            {fprintf(stderr,"WARN: max_ucs_lines\n");
+            break;}
+            if (h+sub_top_margin > obj->y) {	// out of the screen so end parsing
 		obj->y -= lasth - vo_font->height;	// correct the y position
 		fprintf(stderr,"WARN: Out of screen at Y: %d\n",obj->y);
 		obj->params.subtitle.lines=obj->params.subtitle.lines-1;
@@ -428,7 +430,7 @@ inline static void vo_update_text_sub(mp_osd_obj_t* obj,int dxs,int dys){
 	    obj->params.subtitle.xtbl[xtblc++] = ((dxs-sub_right_margin-sub_left_margin - xsize) / 2)+sub_left_margin;
 	    if (xmin > (((dxs-sub_right_margin-sub_left_margin - xsize) / 2)+sub_left_margin))
 		xmin = ((dxs-sub_right_margin-sub_left_margin - xsize) / 2)+sub_left_margin;
-		if (xmax < (((dxs-sub_right_margin-sub_left_margin + xsize) / 2)+sub_left_margin))
+            if (xmax < (((dxs-sub_right_margin-sub_left_margin + xsize) / 2)+sub_left_margin))
 		xmax = ((dxs-sub_right_margin-sub_left_margin + xsize) / 2)+sub_left_margin;
 /* 		fprintf(stderr,"lm %d rm: %d xm:%d xs:%d\n",sub_left_margin,sub_right_margin,xmax,xsize); */
 	    tmp = (tmp_otp->next == NULL) ? NULL : tmp_otp->next->ott;
@@ -445,15 +447,15 @@ inline static void vo_update_text_sub(mp_osd_obj_t* obj,int dxs,int dys){
 		obj->params.subtitle.utbl[utblc++] = ' ';
 	    }
 	    obj->params.subtitle.utbl[utblc - 1] = 0;
-		obj->y -= vo_font->height;
+            obj->y -= vo_font->height;
 	}
 	if ( sub_max_lines<obj->params.subtitle.lines)
-	  sub_max_lines=obj->params.subtitle.lines;
+            sub_max_lines=obj->params.subtitle.lines;
 	if ( sub_max_font_height<vo_font->height)
-	  sub_max_font_height=vo_font->height;
+            sub_max_font_height=vo_font->height;
 	if ( sub_max_bottom_font_height<vo_font->pic_a[vo_font->font[40]]->h)
-	  sub_max_bottom_font_height=vo_font->pic_a[vo_font->font[40]]->h;
-    if(obj->params.subtitle.lines)
+            sub_max_bottom_font_height=vo_font->pic_a[vo_font->font[40]]->h;
+        if(obj->params.subtitle.lines)
 	    obj->y = dys - sub_bottom_margin -((obj->params.subtitle.lines) * vo_font->height); /* + vo_font->pic_a[vo_font->font[40]]->h);*/
 
 	// free memory
@@ -470,20 +472,20 @@ inline static void vo_update_text_sub(mp_osd_obj_t* obj,int dxs,int dys){
 	    }
 	    free(pmt);
 	} else {
-		fprintf(stderr,"WARN: Subtitles requested but not found.\n");
+            fprintf(stderr,"WARN: Subtitles requested but not found.\n");
 	}
 
     }
 
-	subs_height=((obj->params.subtitle.lines-1) * vo_font->height)+vo_font->pic_a[vo_font->font[40]]->h;
-	/* fprintf(stderr,"^1 bby1:%d bby2:%d h:%d dys:%d oy:%d sa:%d sh:%d f:%d\n",obj->bbox.y1,obj->bbox.y2,h,dys,obj->y,sub_alignment,subs_height,font); */
-	if (sub_alignment == 2)
+    subs_height=((obj->params.subtitle.lines-1) * vo_font->height)+vo_font->pic_a[vo_font->font[40]]->h;
+    /* fprintf(stderr,"^1 bby1:%d bby2:%d h:%d dys:%d oy:%d sa:%d sh:%d f:%d\n",obj->bbox.y1,obj->bbox.y2,h,dys,obj->y,sub_alignment,subs_height,font); */
+    if (sub_alignment == 2)
         obj->y = dys * sub_pos / 100 - sub_bottom_margin-subs_height;
     else if (sub_alignment == 1)
         obj->y = (((dys * sub_pos / 100) - sub_bottom_margin - sub_top_margin - subs_height + vo_font->height))/2;
     else
         obj->y = sub_top_margin;
-	if (obj->y < sub_top_margin)
+    if (obj->y < sub_top_margin)
         obj->y = sub_top_margin;
     if (obj->y > dys - sub_bottom_margin-vo_font->height)
         obj->y = dys - sub_bottom_margin-vo_font->height;
@@ -495,79 +497,79 @@ inline static void vo_update_text_sub(mp_osd_obj_t* obj,int dxs,int dys){
     obj->bbox.x1=xmin-3;
     obj->bbox.x2=xmax+3+vo_font->spacewidth;
 
-	/* if ( obj->bbox.x2>=dxs-sub_right_margin-20)
-	{
-		obj->bbox.x2=dxs;
-	}
+    /* if ( obj->bbox.x2>=dxs-sub_right_margin-20)
+       {
+       obj->bbox.x2=dxs;
+       }
 
-	 */
-	obj->bbox.y1=obj->y-3;
+    */
+    obj->bbox.y1=obj->y-3;
 //    obj->bbox.y2=obj->y+obj->params.subtitle.lines*vo_font->height;
     obj->flags|=OSDFLAG_BBOX;
 
     alloc_buf(obj);
-	y = obj->y;
-	/* fprintf(stderr,"^2 bby1:%d bby2:%d h:%d dys:%d oy:%d sa:%d sh:%d\n",obj->bbox.y1,obj->bbox.y2,h,dys,obj->y,sub_alignment,subs_height); */
+    y = obj->y;
+    /* fprintf(stderr,"^2 bby1:%d bby2:%d h:%d dys:%d oy:%d sa:%d sh:%d\n",obj->bbox.y1,obj->bbox.y2,h,dys,obj->y,sub_alignment,subs_height); */
 
 
-	switch(vo_sub->alignment) {
-	case SUB_ALIGNMENT_HLEFT:
-	    obj->alignment |= 0x1;
-	    break;
-	case SUB_ALIGNMENT_HCENTER:
-	    obj->alignment |= 0x0;
-	    break;
-	case SUB_ALIGNMENT_HRIGHT:
-	default:
-	    obj->alignment |= 0x2;
+    switch(vo_sub->alignment) {
+    case SUB_ALIGNMENT_HLEFT:
+        obj->alignment |= 0x1;
+        break;
+    case SUB_ALIGNMENT_HCENTER:
+        obj->alignment |= 0x0;
+        break;
+    case SUB_ALIGNMENT_HRIGHT:
+    default:
+        obj->alignment |= 0x2;
     }
-	i=j=prev_j=0;
+    i=j=prev_j=0;
     if ((l = obj->params.subtitle.lines))
-	{
-	  for(counter = dxs-sub_right_margin-sub_left_margin; i < l; ++i)
+    {
+        for(counter = dxs-sub_right_margin-sub_left_margin; i < l; ++i)
 	    if (obj->params.subtitle.xtbl[i] < counter) counter = obj->params.subtitle.xtbl[i];
-	  for (i = 0; i < l; ++i)
-	    {
-	      switch (obj->alignment&0x3)
-		    {
-		      case 1:
-		        // left
-				if ( sub_justify)
-				  x=xmin;
-				else
-				  x = counter;
-				break;
-		      case 2:
-		        // right
-		        x = 2 * obj->params.subtitle.xtbl[i] - counter - ((obj->params.subtitle.xtbl[i] == counter) ? 0 : 1);
-		        break;
-		      default:
-		        //center
-		        x = obj->params.subtitle.xtbl[i];
-	        }
-		  prevc = -1;
-	      while ((c=obj->params.subtitle.utbl[j++]))
-		    {
-			  x += kerning(vo_font,prevc,c);
-			  if (((font=vo_font->font[c])>=0))
-		        {
-				  /* fprintf(stderr,"^3 vfh:%d vfh+y:%d odys:%d\n",vo_font->pic_a[font]->h,vo_font->pic_a[font]->h+y,obj->dys); */
-				  draw_alpha_buf(obj,x,y,
-			      vo_font->width[c],
-			      vo_font->pic_a[font]->h+y<obj->dys-sub_bottom_margin ? vo_font->pic_a[font]->h : obj->dys-sub_bottom_margin-y,
-				  vo_font->pic_b[font]->bmp+vo_font->start[c],
-			      vo_font->pic_a[font]->bmp+vo_font->start[c],
-			      vo_font->pic_a[font]->w);
-		        }
-	          x+=vo_font->width[c]+vo_font->charspace;
-              prevc = c;
-		    }
-		  if ( sub_max_chars<(j-prev_j))
-		    sub_max_chars=(j-prev_j);
-		  prev_j=j;
-		  y+=vo_font->height;
-	    }
-  /* Here you could retreive the buffers*/
+        for (i = 0; i < l; ++i)
+        {
+            switch (obj->alignment&0x3)
+            {
+            case 1:
+                // left
+                if ( sub_justify)
+                    x=xmin;
+                else
+                    x = counter;
+                break;
+            case 2:
+                // right
+                x = 2 * obj->params.subtitle.xtbl[i] - counter - ((obj->params.subtitle.xtbl[i] == counter) ? 0 : 1);
+                break;
+            default:
+                //center
+                x = obj->params.subtitle.xtbl[i];
+            }
+            prevc = -1;
+            while ((c=obj->params.subtitle.utbl[j++]))
+            {
+                x += kerning(vo_font,prevc,c);
+                if (((font=vo_font->font[c])>=0))
+                {
+                    /* fprintf(stderr,"^3 vfh:%d vfh+y:%d odys:%d\n",vo_font->pic_a[font]->h,vo_font->pic_a[font]->h+y,obj->dys); */
+                    draw_alpha_buf(obj,x,y,
+                                   vo_font->width[c],
+                                   vo_font->pic_a[font]->h+y<obj->dys-sub_bottom_margin ? vo_font->pic_a[font]->h : obj->dys-sub_bottom_margin-y,
+                                   vo_font->pic_b[font]->bmp+vo_font->start[c],
+                                   vo_font->pic_a[font]->bmp+vo_font->start[c],
+                                   vo_font->pic_a[font]->w);
+                }
+                x+=vo_font->width[c]+vo_font->charspace;
+                prevc = c;
+            }
+            if ( sub_max_chars<(j-prev_j))
+                sub_max_chars=(j-prev_j);
+            prev_j=j;
+            y+=vo_font->height;
+        }
+        /* Here you could retreive the buffers*/
 
     }
 }
